@@ -5,7 +5,7 @@ class Client():
         if address is not None:
             self.address = address
         else:
-            self.address = "http://service:8000"
+            self.address = "http://127.0.0.1:8000"
             
         self.download_url = self.address + "/download/"
         self.upload_url = self.address + "/upload/"
@@ -22,8 +22,10 @@ class Client():
             if json["success"] == True:
                 return True
             else:
+                print(json)
                 return False
         except Exception as exception:
+            print(exception)
             return False
     
     def download(self, file_path):
